
# Slot: subsets


list of subsets referenced in this model

URI: [linkml:subsets](https://w3id.org/linkml/subsets)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..\*</sub> [SubsetDefinition](SubsetDefinition.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
